Getting Started — django-xliff 0.1 documentation

django-xliff 0.1 documentation

# Getting Started

- Table of Contents
- index
  next
  previous

# Getting Started

## Installation

1. Using `pip` or `easy_install`.

       pip install django-xliff

   or

       easy_install django-xliff

2. Add `"xliff",` to your `INSTALLED_APPS` setting.

3. Create a `SERIALIZATION_MODULES` setting where the key is the file extension (`xliff` or `xlf`) and the value is `'xliff.xliff_serializer'`:

       SERIALIZATION_MODULES = {'xliff': 'xliff.xliff_serializer'}

## Exporting and Importing

Use Django’s serialization tools. For example, using the dumpdata command:

    django-admin.py dumpdata --format=xliff simpleapp > data.xliff

You can use the loaddata command as well:

    django-admin.py loaddata data.xliff